==> mx-compton_18.11.tar.xz: mx-compton/translations/mx-compton_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>mxcompton</name>
    <message>
        <location filename="../mxcompton.ui" line="14"/>
        <source>MX Compton Manager</source>
        <translation>MX Compton Manager</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="88"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="91"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="98"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="108"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="119"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="134"/>
        <source>Xfce compositor will be disabled</source>
        <translation>Compositor de Xfce será desactivado</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="137"/>
        <location filename="../mxcompton.cpp" line="110"/>
        <location filename="../mxcompton.cpp" line="146"/>
        <source>Launch Compton</source>
        <translation>Lanzar Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="149"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Lanzar herramienta de configuración compton-conf</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="152"/>
        <source>Compton settings</source>
        <translation>Ajustes Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="164"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar compton.conf directamente en editor de texto</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="167"/>
        <source>Edit compton.conf</source>
        <translation>Editar compton.conf</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="195"/>
        <source>Launch Compton at login</source>
        <translation>Lanzar Compton a login</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="107"/>
        <source>Stop Compton</source>
        <translation>Parar Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="167"/>
        <source>About MX Compton</source>
        <translation>Acerca de MX Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <location filename="../mxcompton.cpp" line="185"/>
        <source>MX Compton</source>
        <translation>MX Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="169"/>
        <source>Configure Compton Settings</source>
        <translation>Configurar ajustes de Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="171"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="172"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="173"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
</TS>

==> mx-compton_19.01.tar.xz: mx-compton/translations/mx-compton_es.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>mxcompton</name>
    <message>
        <location filename="../mxcompton.ui" line="14"/>
        <source>MX Compton Manager</source>
        <translation>MX Gestor Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="88"/>
        <source>Quit application</source>
        <translation>Terminar aplicación</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="91"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="98"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="108"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="119"/>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="134"/>
        <source>Xfce compositor will be disabled</source>
        <translation>Compositor de Xfce será desactivado</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="137"/>
        <location filename="../mxcompton.cpp" line="110"/>
        <location filename="../mxcompton.cpp" line="146"/>
        <source>Launch Compton</source>
        <translation>Lanzar Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="149"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Lanzar herramienta de configuración compton-conf</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="152"/>
        <source>Compton settings</source>
        <translation>Ajustes Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="164"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Editar compton.conf directamente en editor de texto</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="167"/>
        <source>Edit compton.conf</source>
        <translation>Editar compton.conf</translation>
    </message>
    <message>
        <location filename="../mxcompton.ui" line="195"/>
        <source>Launch Compton at login</source>
        <translation>Lanzar Compton a login</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="107"/>
        <source>Stop Compton</source>
        <translation>Parar Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="167"/>
        <source>About MX Compton</source>
        <translation>Acerca de MX Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <location filename="../mxcompton.cpp" line="185"/>
        <source>MX Compton</source>
        <translation>MX Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="168"/>
        <source>Version: </source>
        <translation>Versión:</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="169"/>
        <source>Configure Compton Settings</source>
        <translation>Configurar ajustes de Compton</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="171"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Derechos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="172"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxcompton.cpp" line="173"/>
        <location filename="../mxcompton.cpp" line="175"/>
        <source>License</source>
        <translation>Licencia</translation>
    </message>
</context>
</TS>
